@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Page;
 
-# $Id: Page.pm,v 1.8 2003/06/09 11:46:57 lachoy Exp $
+# $Id: Page.pm,v 1.10 2003/06/25 14:10:49 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -11,12 +11,13 @@ use DateTime;
 use DateTime::Duration;
 use File::Basename;
 use File::Spec;
+use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log OI_OK OI_ERROR );
-use OpenInteract2::Context   qw( CTX DEBUG LOG );
+use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 # 52 weeks -- default expiration for page
 
@@ -61,6 +62,8 @@ sub help {
 
 sub _get_task {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
     my ( $task );
     if ( $request->url_relative !~ /^page$/i ) {
@@ -70,7 +73,8 @@ sub _get_task {
         $task = $request->task_name
                 || $self->task_default;
     }
-    DEBUG && LOG( LDEBUG, "Task found from _get_task: [$task]" );
+    $log->is_debug &&
+        $log->debug( "Task found from _get_task: [$task]" );
     return $task;
 }
 
@@ -102,12 +106,14 @@ sub _search_criteria_customize {
 
 sub directory_list {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $page_class = CTX->lookup_object( 'page' );
     my $selected_dir = CTX->request->param( 'selected_dir' );
     my %params = ( selected_dir => $selected_dir );
     $params{dir_list} = eval { $page_class->list_directories };
     if ( $@ ) {
-        LOG( LERROR, "Cannot fetch directories: $@" );
+        $log->error( "Cannot fetch directories: $@" );
         $self->param_add( error_msg => "Cannot retrieve directories: $@" );
         $params{dir_list}   = [];
     }
@@ -132,9 +138,11 @@ sub directory_list {
 
 sub specify_subdirectory {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $parent_dir = CTX->request->param( 'parent_directory' );
     unless ( $self->_check_location_writable( $parent_dir ) ) {
-        LOG( LERROR, "Insufficient permissions to add subdirectory" );
+        $log->error( "Insufficient permissions to add subdirectory" );
         my $error_msg = "Insufficient permissions to add " .
                         "subdirectory. No action taken.";
         $self->param_add( error_msg => $error_msg );
@@ -151,10 +159,12 @@ sub specify_subdirectory {
 
 sub add_subdirectory {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
     my $parent_dir = $request->param( 'parent_directory' );
     unless ( $self->_check_location_writable( $parent_dir ) ) {
-        LOG( LERROR, "Insufficient permissions to add subdirectory" );
+        $log->error( "Insufficient permissions to add subdirectory" );
         my $error_msg = "Insufficient permissions to add subdirectory. " .
                         "No action taken.";
         $self->param_add( error_msg => $error_msg );
@@ -196,6 +206,8 @@ sub add_subdirectory {
 
 sub remove_directory {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
     my $page_class = CTX->lookup_object( 'page' );
     my $confirm = lc $request->param( 'remove_directory_confirm' );
@@ -203,14 +215,16 @@ sub remove_directory {
                          $request->param( 'directory' ) );
 
     if ( $confirm eq 'no' ) {
-        DEBUG && LOG( LDEBUG, "Directory removal cancelled" );
+        $log->is_debug &&
+            $log->debug( "Directory removal cancelled" );
         $self->param( location => $directory );
         $self->param_add( status_msg => 'Directory removal cancelled' );
         return $self->execute({ task => 'display' });
     }
 
     if ( $confirm ne 'yes' ) {
-        DEBUG && LOG( LDEBUG, "Need confirmation for directory removal" );
+        $log->is_debug &&
+            $log->debug( "Need confirmation for directory removal" );
         return $self->generate_content(
                          { directory => $directory },
                          { name => 'base_page::directory_remove_confirm' } );
@@ -223,7 +237,7 @@ sub remove_directory {
     $directory =~ s|/$||;
 
     if ( ! $directory or $directory eq '/' ) {
-        LOG( LERROR, "Empty/root dir given [$directory]; no action taken" );
+        $log->error( "Empty/root dir given [$directory]; no action taken" );
         $self->param_add( error_msg =>  'Directory removal cancelled: must ' .
                                         'specify a non-root directory' );
         return $self->generate_content(
@@ -232,7 +246,7 @@ sub remove_directory {
     }
 
     unless ( $self->_check_location_writable( $directory ) ) {
-        LOG( LERROR, "Insufficient permissions to remove directory" );
+        $log->error( "Insufficient permissions to remove directory" );
         my $error_msg = "Insufficient permissions to remove directory." .
                         "No action taken.";
         $self->param_add( error_msg => $error_msg );
@@ -241,24 +255,29 @@ sub remove_directory {
                          { name => 'base_page::directory_edit_status' } );
     }
 
-    DEBUG && LOG( LDEBUG, "Removal of dir [$directory] confirmed" );
+    $log->is_debug &&
+        $log->debug( "Removal of dir [$directory] confirmed" );
     eval {
         my $pages_in_dir = $page_class->fetch_group(
                                    { where => 'directory LIKE ?',
                                      value => [ "$directory%" ] });
         foreach my $page ( @{ $pages_in_dir } ) {
-            DEBUG && LOG( LDEBUG, "Removing page [$page->{location}]" );
+            $log->is_debug &&
+                $log->debug( "Removing page [$page->{location}]" );
             $page->remove;
-            DEBUG && LOG( LDEBUG, "Removed page [$page->{location}] ok" );
+            $log->is_debug &&
+                $log->debug( "Removed page [$page->{location}] ok" );
         }
         my $full_dir = File::Spec->catdir( CTX->server_config->{dir}{html},
                                            $directory );
-        DEBUG && LOG( LDEBUG, "Removing directory [$full_dir]" );
+        $log->is_debug &&
+            $log->debug( "Removing directory [$full_dir]" );
         File::Path::rmtree( $full_dir );
-        DEBUG && LOG( LDEBUG, "Removed directory [$full_dir] ok" );
+        $log->is_debug &&
+            $log->debug( "Removed directory [$full_dir] ok" );
     };
     if ( $@ ) {
-        LOG( LERROR, "Error in removal process: $@" );
+        $log->error( "Error in removal process: $@" );
         my $error_msg = "Failed to remove directory tree. Files may " .
                         "be in inconsistent state. (Error: $@)";
         $self->param_add( error_msg => $error_msg );
@@ -266,11 +285,13 @@ sub remove_directory {
                          { action    => 'remove_directory' },
                          { name => 'base_page::directory_edit_status' } );
     }
-    DEBUG && LOG( LDEBUG, "Removal of directory [$directory] ok" );
+    $log->is_debug &&
+        $log->debug( "Removal of directory [$directory] ok" );
     my @pieces = split( '/', $directory );
     pop @pieces;
     my $view_directory = join( '/', @pieces );
-    DEBUG && LOG( LDEBUG, "Trying to view directory [$view_directory]" );
+    $log->is_debug &&
+        $log->debug( "Trying to view directory [$view_directory]" );
     my $status_msg = "Removed directory [$directory] ok";
     return $self->generate_content(
                          { status_msg       => $status_msg,
@@ -286,9 +307,11 @@ sub remove_directory {
 
 sub specify_rename {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $location = CTX->request->param( 'location' );
     unless ( $self->_check_location_writable( $location ) ) {
-        LOG( LERROR, "Insufficient permissions to rename file" );
+        $log->error( "Insufficient permissions to rename file" );
         my $error_msg = "Insufficient permissions to rename file. " .
                         "No action taken.";
         $self->param_add( error_msg => $error_msg );
@@ -300,7 +323,7 @@ sub specify_rename {
         CTX->lookup_object( 'page' )->fetch( $location )
     };
     if ( $@ ) {
-        LOG( LERROR, "Failed to get page [$location]: $@" );
+        $log->error( "Failed to get page [$location]: $@" );
         $self->param_add( error_msg => "Failed to retrieve page for " .
                                        "specified location [$location]" );
     }
@@ -311,16 +334,19 @@ sub specify_rename {
 
 sub rename_file {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
     my $page_class = CTX->lookup_object( 'page' );
     my $old_location = $request->param( 'old_location' );
     my $new_location = $page_class->clean_name(
                               $request->param( 'new_location' ) );
-    DEBUG && LOG( LDEBUG, "Trying to rename [$old_location] -> ",
-                          "[$new_location]" );
+    $log->is_debug &&
+        $log->debug( "Trying to rename [$old_location] -> ",
+                     "[$new_location]" );
     unless ( $self->_check_location_writable( $old_location ) && 
              $self->_check_location_writable( $new_location ) ) {
-        LOG( LERROR, "Insufficient permissions to rename file" );
+        $log->error( "Insufficient permissions to rename file" );
         my $error_msg = "Insufficient permissions to rename file. " .
                         "No action taken.";
         $self->param_add( error_msg => $error_msg );
@@ -331,7 +357,7 @@ sub rename_file {
 
     my $old_page = eval { $page_class->fetch( $old_location ) };
     if ( $@ or ! $old_page ) {
-        LOG( LERROR, "Old location [$old_location] does not exist ",
+        $log->error( "Old location [$old_location] does not exist ",
                      "or error fetching it [$@]" );
         my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
                         "[$old_location] does not exist";
@@ -340,11 +366,12 @@ sub rename_file {
                          {},
                          { name => 'base_page::page_edit_status' } );
     }
-    DEBUG && LOG( LDEBUG, "Old location fetched ok" );
+    $log->is_debug &&
+        $log->debug( "Old location fetched ok" );
 
     my $new_page = eval { $page_class->fetch( $new_location ) };
     if ( $new_page ) {
-        LOG( LERROR, "New location [$new_location] already exists" );
+        $log->error( "New location [$new_location] already exists" );
         my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
                         "[$new_location] already exists!";
         $self->param_add( error_msg => $error_msg );
@@ -352,12 +379,13 @@ sub rename_file {
                          {},
                          { name => 'base_page::page_edit_status' } );
     }
-    DEBUG && LOG( LDEBUG, "New location does not exist (good)" );
+    $log->is_debug &&
+        $log->debug( "New location does not exist (good)" );
 
     $old_page->{location} = $new_location;
     eval { $old_page->rename_content( $old_location ) };
     if ( $@ ) {
-        LOG( LERROR, "Error renaming content: $@" );
+        $log->error( "Error renaming content: $@" );
         my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
                         "Failure: $@.";
         $self->param_add( error_msg => $error_msg );
@@ -365,13 +393,15 @@ sub rename_file {
                          {},
                          { name => 'base_page::page_edit_status' } );
     }
-    DEBUG && LOG( LDEBUG, "Page content renamed successfully" );
+    $log->is_debug &&
+        $log->debug( "Page content renamed successfully" );
 
-    DEBUG && LOG( LDEBUG, "Saving page with new location ",
+    $log->is_debug &&
+        $log->debug( "Saving page with new location ",
                           "[$old_page->{location}]" );
     eval { $old_page->save({ use_id => $old_location }) };
     if ( $@ ) {
-        LOG( LERROR, "Error saving page object: $@" );
+        $log->error( "Error saving page object: $@" );
         my $error_msg = "Cannot rename [$old_location] to [$new_location]: " .
                         "Error saving page with new location: $@";
         $self->param_add( error_msg => $error_msg );
@@ -379,7 +409,8 @@ sub rename_file {
                          {},
                          { name => 'base_page::page_edit_status' } );
     }
-    DEBUG && LOG( LDEBUG, "Page saved with new location ok" );
+    $log->is_debug &&
+        $log->debug( "Page saved with new location ok" );
     $self->param_add( status_msg => "File renamed ok" );
     return $self->generate_content(
                          { directory  => $old_page->{directory},
@@ -389,6 +420,8 @@ sub rename_file {
 
 sub _check_location_writable {
     my ( $self, $location ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
     my $level = eval {
         CTX->lookup_object( 'page' )
@@ -397,7 +430,7 @@ sub _check_location_writable {
                               group     => $request->auth_group })
     };
     if ( $@ ) {
-        LOG( LERROR, "Error looking up security for [$location]: $@" );
+        $log->error( "Error looking up security for [$location]: $@" );
     }
     return ( $level >= SEC_LEVEL_WRITE );
 }
@@ -408,10 +441,13 @@ sub _check_location_writable {
 
 sub fetch_object {
     my ( $self, $id, @id_field ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $existing_location = CTX->request->param( 'old_location' );
     my $fetch_id = ( $id =~ m|^/| ) ? $id : "/$id";
-    DEBUG && LOG( LDEBUG, "Pre-fetch: [Exist: $existing_location] ",
-                          "[New: $fetch_id]" );
+    $log->is_debug &&
+        $log->debug( "Pre-fetch: [Exist: $existing_location] ",
+                     "[New: $fetch_id]" );
     return ( $existing_location )
              ? $self->SUPER::fetch_object( $existing_location, @id_field )
              : $self->SUPER::fetch_object( $fetch_id, @id_field );
@@ -420,6 +456,8 @@ sub fetch_object {
 
 sub _modify_check_upload {
     my ( $self, $page ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
 
     # See if the upload should be there -- note that
@@ -428,7 +466,8 @@ sub _modify_check_upload {
 
     my $has_upload = $request->param_toggled( 'use_upload' );
     if ( $has_upload eq 'yes' ) {
-        DEBUG && LOG( LDEBUG, "Handling file upload" );
+        $log->is_debug &&
+            $log->debug( "Handling file upload" );
         my ( $type, $msg ) = $self->_handle_uploaded_file( $page );
         return ( $type, $msg ) if ( $type );
     }
@@ -439,6 +478,8 @@ sub _modify_check_upload {
 
 sub _update_customize {
     my ( $self, $page, $old_data, $update_params ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
 
     # TODO: this isn't correct return value
@@ -461,8 +502,9 @@ sub _update_customize {
         my $filename = $page_class->clean_filename(
                                    $page->{tmp_upload}{filename} );
         $page->{location} = join( '/', $dir, $filename );
-        DEBUG && LOG( LDEBUG, "Set location to [$page->{location}] from",
-                              "filename reported by client [$filename]" );
+        $log->is_debug &&
+            $log->debug( "Set location to [$page->{location}] from",
+                         "filename reported by client [$filename]" );
 
         # Check to see if this location is already in the
         # database. (For non-simple pages this is done in the normal
@@ -488,17 +530,20 @@ sub _update_customize {
         if ( $old_data->{location} and
             $page->{location} ne $old_data->{location} ) {
             $opts{use_id} = $old_data->{location};
-            DEBUG && LOG( LDEBUG, "This should be an UPDATE where ",
-                          "we change the primary key from  ",
-                          "[$old_data->{location}] to [$page->{location}]" );
+            $log->is_debug &&
+                $log->debug( "This should be an UPDATE where ",
+                             "we change the primary key from  ",
+                             "[$old_data->{location}] to [$page->{location}]" );
         }
     }
 
     # Ensure that the location is clean
 
-    DEBUG && LOG( LDEBUG, "Location before clean [$page->{location}]" );
+    $log->is_debug &&
+        $log->debug( "Location before clean [$page->{location}]" );
     $page->{location} = $page_class->clean_location( $page->{location} );
-    DEBUG && LOG( LDEBUG, "Location after clean [$page->{location}]" );
+    $log->is_debug &&
+        $log->debug( "Location after clean [$page->{location}]" );
 
     $page->{expires_on} ||= DateTime->now + DEFAULT_EXPIRE;
     $page->{mime_type} ||= 'text/html';
@@ -508,8 +553,9 @@ sub _update_customize {
     # list of fields to be processed by the FullText indexer
 
     unless ( $self->_is_displayable( $page->{mime_type} ) ) {
-        DEBUG && LOG( LDEBUG, "Not displayable [$page->{mime_type}];",
-                              "don't scan content for index" );
+        $log->is_debug &&
+            $log->debug( "Not displayable [$page->{mime_type}];",
+                         "don't scan content for index" );
         $page->{is_file} = 'yes';
         if ( $page->CONFIG->{fulltext_field} ) {
             $opts{fulltext_field} = [ grep ! /^content$/,
@@ -580,9 +626,12 @@ sub display_form {
 
 sub _show {
     my ( $self ) = @_;
-    DEBUG && LOG( LDEBUG, "Edit status of page: ",
-                  "[edit: ", $self->param( 'edit' ), "] ",
-                  "[new object: ", $self->param( 'is_new_object' ), "]" );
+    my $log = get_logger( LOG_APP );
+
+    $log->is_debug &&
+        $log->debug( "Edit status of page: ",
+                     "[edit: ", $self->param( 'edit' ), "] ",
+                     "[new object: ", $self->param( 'is_new_object' ), "]" );
     my $page_class = CTX->lookup_object( 'page' );
     my $page = $self->param( 'page' );
     if ( $self->param( 'is_new_object' ) ) {
@@ -597,20 +646,23 @@ sub _show {
 
     unless ( $page ) {
         $location = $self->_get_location;
-        DEBUG && LOG( LDEBUG, "No page passed in, try and find page object ",
-                              "or dir index matching [$location]" );
+        $log->is_debug &&
+            $log->debug( "No page passed in, try and find page object ",
+                         "or dir index matching [$location]" );
         my $item = eval { $page_class->page_by_location( $location ) };
         if ( $@ ) {
-            LOG( LERROR, "Caught error when fetching page by location: $@" );
+            $log->error( "Caught error when fetching page by location: $@" );
             $self->_fail_page_fetch( $location, $@ );
         }
         if ( $item and $item->isa( CTX->lookup_object( 'page_directory' ) ) ) {
-            DEBUG && LOG( LDEBUG, "Returned item is a page_directory ",
-                                  "object, running directory handler." );
+            $log->is_debug &&
+                $log->debug( "Returned item is a page_directory ",
+                             "object, running directory handler." );
             return $self->_run_directory_handler( $item, $location );
         }
-        DEBUG && LOG( LDEBUG, "Returned item is either a page object ",
-                              "or nothing at all: $item" );
+        $log->is_debug &&
+            $log->debug( "Returned item is either a page object ",
+                         "or nothing at all: $item" );
         $page = $item;
     }
 
@@ -622,7 +674,7 @@ sub _show {
     unless ( $page or $do_edit ) {
         $self->response->content_type( 'text/html' );
         $location ||= $page->{location};
-        LOG( LWARN, "Page for [$location] doesn't exist; did not specify ",
+        $log->warn( "Page for [$location] doesn't exist; did not specify ",
                     "edit mode. Bail." );
         return $self->generate_content({ url => $location },
                                        { name => 'error_not_found' } );
@@ -649,6 +701,8 @@ sub _show {
 
 sub _show_displayable_page {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $page = $self->param( 'page' );
     unless ( ref $page ) {
         oi_error "Must set 'page' in action parameter to display";
@@ -657,7 +711,8 @@ sub _show_displayable_page {
     # Ensure the page is active
 
     unless ( $self->_is_active( $page ) ) {
-        DEBUG && LOG( LDEBUG, "Page not active; return error" );
+        $log->is_debug &&
+            $log->debug( "Page not active; return error" );
         return $self->generate_content(
                          {}, { name => 'error_object_inactive' } );
     }
@@ -665,12 +720,13 @@ sub _show_displayable_page {
     # Follow the alias chain to its end
 
     while ( $page->{storage} eq 'alias' ) {
-        DEBUG && LOG( LDEBUG, "Trying to find aliased content from ",
-                              "location [$page->{content_location}]" );
+        $log->is_debug &&
+            $log->debug( "Trying to find aliased content from ",
+                         "location [$page->{content_location}]" );
         $page = eval { $page->page_by_location(
                                    $page->{content_location} ) };
         if ( $@ or ! $page ) {
-            LOG( LERROR, "Location for alias [$page->{content_location}]",
+            $log->error( "Location for alias [$page->{content_location}]",
                          "wasn't found: $@" );
             my %params = ( location       => $page->{location},
                            alias_location => $page->{content_location} );
@@ -680,7 +736,8 @@ sub _show_displayable_page {
         }
     }
 
-    DEBUG && LOG( LDEBUG, "Display [$page->{location}] as normal HTML" );
+    $log->is_debug &&
+        $log->debug( "Display [$page->{location}] as normal HTML" );
     $page->fetch_content;
 
     # Use page metadata to modify display
@@ -706,6 +763,8 @@ sub _show_displayable_page {
 
 sub _show_editable_page {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $page = $self->param( 'page' )
                || CTX->lookup_object( 'page' )->new;
     my %params = ();
@@ -720,9 +779,10 @@ sub _show_editable_page {
     else {
         $params{non_editable} = 1;
     }
-    DEBUG && LOG( LDEBUG, "This page should be in an editable form;",
-                          "uneditable content status ",
-                          "[$params{non_editable}]" );
+    $log->is_debug &&
+        $log->debug( "This page should be in an editable form;",
+                     "uneditable content status ",
+                     "[$params{non_editable}]" );
 
     my $tmpl_name = 'page_form';
 
@@ -743,21 +803,27 @@ sub _show_editable_page {
 
 sub _show_nondisplayable_page {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $response = $self->response;
     my $page     = $self->param( 'page' );
     my $full_filename = join( '', CTX->server_config->{dir}{html},
                                   $page->{location} );
     $response->send_file( $full_filename );
-    DEBUG && LOG( LDEBUG, "File being retrieved is not directly",
-                  "displayable. Set 'send_file' to [$page->{location}]" );
+    $log->is_debug &&
+        $log->debug( "File being retrieved is not directly",
+                     "displayable. Set 'send_file' to [$page->{location}]" );
     return undef;
 }
 
 
 sub _fail_page_fetch {
     my ( $self, $location, $error ) = @_;
+    my $log = get_logger( LOG_APP );
+
     $self->response->content_type( 'text/html' );
-    DEBUG && LOG( LDEBUG, "Could not retrieve page. Error [$error]" );
+    $log->is_debug &&
+        $log->debug( "Could not retrieve page. Error [$error]" );
     if ( $error->isa( 'OpenInteract2::Exception::Security' ) ) {
         return $self->generate_content(
                     {}, { name => 'error_object_security' });
@@ -864,6 +930,7 @@ PCOUNT
 
 sub _add_object_boxes {
     my ( $self, $page, $p ) = @_;
+    my $log = get_logger( LOG_APP );
 
     my $box_string = $page->{boxes};
 
@@ -876,7 +943,8 @@ sub _add_object_boxes {
         my @boxes = split /\s+/, $box_string;
         foreach my $box_name ( @boxes ) {
             next if ( $box_name =~ /^\s*$/ );
-            DEBUG && LOG( LDEBUG, "Adding box name [$box_name] from page definition" );
+            $log->is_debug &&
+                $log->debug( "Adding box name [$box_name] from page definition" );
             my $box_params = { name => $box_name };
             if ( $box_name =~ s/^\-// ) {
                 $controller->remove_box( $box_name );
@@ -900,13 +968,16 @@ sub _add_object_boxes {
 
 sub _is_active {
     my ( $self, $page ) = @_;
+    my $log = get_logger( LOG_APP );
 
     if ( $page->{is_active} eq 'no' ) {
-        DEBUG && LOG( LDEBUG, "Page NOT active: 'is_active' false" );
+        $log->is_debug &&
+            $log->debug( "Page NOT active: 'is_active' false" );
         return undef;
     }
     unless ( $page->{active_on} ) {
-        DEBUG && LOG( LDEBUG, "Page active: no 'active_on' date" );
+        $log->is_debug &&
+            $log->debug( "Page active: no 'active_on' date" );
         return 1;
     }
 
@@ -914,32 +985,39 @@ sub _is_active {
     my $now     = DateTime->now;
 
     if ( $active > $now ) {
-        DEBUG && LOG( LDEBUG, "Page NOT active: 'active_on' > today" );
+        $log->is_debug &&
+            $log->debug( "Page NOT active: 'active_on' > today" );
         return undef;
     }
 
     # OK if there's no expiration date, and the active date is ok
 
     unless ( $page->{expires_on} ) {
-        DEBUG && LOG( LDEBUG, "Page active: 'active_on' < today ",
-                              "and no expiration" );
+        $log->is_debug &&
+            $log->debug( "Page active: 'active_on' < today ",
+                         "and no expiration" );
         return 1;
     }
 
     my $expires = $page->{expires_on};
     if ( $now > $expires ) {
-        DEBUG && LOG( LDEBUG, "Page NOT active: 'expires_on' < today" );
+        $log->is_debug &&
+            $log->debug( "Page NOT active: 'expires_on' < today" );
         return undef;
     }
 
-    DEBUG && LOG( LDEBUG, "Page active: 'expires_on' > today" );
+    $log->is_debug &&
+        $log->debug( "Page active: 'expires_on' > today" );
     return 1;
 }
 
 
 sub _handle_uploaded_file {
     my ( $self, $page ) = @_;
-    DEBUG && LOG( LDEBUG, "User is requesting content from uploaded file" );
+    my $log = get_logger( LOG_APP );
+
+    $log->is_debug &&
+        $log->debug( "User is requesting content from uploaded file" );
     my $upload  = CTX->request->upload( 'content_upload' );
     unless ( $upload ) {
         my $error_msg = 'You checked off that you wanted to upload a ' .
@@ -950,10 +1028,11 @@ sub _handle_uploaded_file {
     $page->{tmp_upload} = { filename => $upload->filename,
                             size     => $upload->size,
                             type     => $upload->content_type };
-    DEBUG && LOG( LDEBUG, "Upload seems to be retrieved ok. ",
-                          "[Filename: $page->{tmp_upload}{filename}] ",
-                          "[Size: $page->{tmp_upload}{size}] ",
-                          "[Type: $page->{tmp_upload}{type}]" );
+    $log->is_debug &&
+        $log->debug( "Upload seems to be retrieved ok. ",
+                     "[Filename: $page->{tmp_upload}{filename}] ",
+                     "[Size: $page->{tmp_upload}{size}] ",
+                     "[Type: $page->{tmp_upload}{type}]" );
     $page->{size} = $upload->size;
     if ( $self->_is_displayable( $page->{mime_type} ) ) {
         my $fh = $upload->fh;
@@ -1029,7 +1108,7 @@ L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
+Copyright (c) 2001-2003 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
