@@ -1,20 +1,23 @@
 package OpenInteract2::FullText;
 
-# $Id: FullText.pm,v 1.1 2003/03/27 14:04:01 lachoy Exp $
+# $Id: FullText.pm,v 1.4 2003/07/03 05:54:58 lachoy Exp $
 
 use strict;
-use Lingua::Stem             ();
 use DBI                      qw( SQL_VARCHAR SQL_INTEGER );
-use Data::Dumper             qw( Dumper );
+use Lingua::Stem             ();
+use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
-use OpenInteract2::Context   qw( CTX DEBUG LOG );
+use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
 BEGIN {
     eval { require OpenInteract2::FullTextIterator };
 }
 
-$OpenInteract2::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::FullText::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+
+# TODO: Set this in the server config
+use constant DS_NAME => 'main';
 
 use constant COLUMN_GROUP    => 'listing';
 use constant SQL_ORDER_KEY   => 0;
@@ -43,9 +46,11 @@ my @SQL_FIELD_NAMES = qw/ object_key term occur /;
 
 sub create_class_index {
     my ( $class ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $iter = eval { $class->fetch_iterator };
     if ( $@ ) {
-        LOG( LERROR, "Cannot get objects from $class for indexing: $@" );
+        $log->error( "Cannot get objects from $class for indexing: $@" );
         return undef;
     }
     my $count = 0;
@@ -70,14 +75,17 @@ sub create_class_index {
 
 sub search_fulltext_index {
     my ( $class, $p ) = @_;
+    my $log = get_logger( LOG_APP );
+
     return [] unless ( scalar @{ $p->{search_terms} } );
 
     $p->{return}          ||= 'object';
     $p->{search_type}     ||= 'any';
 
-    DEBUG && LOG( LDEBUG, "Searching for $p->{search_type} terms: ",
-                          join( ',', @{ $p->{search_terms} } ),
-                          "returning $p->{return}" );
+    $log->is_debug &&
+        $log->debug( "Searching for $p->{search_type} terms: ",
+                     join( ',', @{ $p->{search_terms} } ),
+                     "returning $p->{return}" );
 
     # after this assignment, @fixed_search is filled with stemmed,
     # lowercased non-STOPWORDS from the terms that the user has given us
@@ -153,10 +161,13 @@ sub _fulltext_object_listing {
 
 sub ruleset_factory {
     my ( $class, $rs_table ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $obj_class = ref $class || $class;
     push @{ $rs_table->{post_save_action} }, \&reindex_object;
     push @{ $rs_table->{post_remove_action} }, \&remove_object_from_index;
-    DEBUG && LOG( LDEBUG, "Installed post_save for $obj_class" );
+    $log->is_debug &&
+        $log->debug( "Installed post_save for $obj_class" );
     return __PACKAGE__;
 }
 
@@ -166,15 +177,20 @@ sub ruleset_factory {
 
 sub reindex_object {
     my ( $self, $p ) = @_;
-    DEBUG && LOG( LINFO, "Indexing [", ref $self, ": ", $self->id, "]" );
+    my $log = get_logger( LOG_APP );
+
+    $log->is_info &&
+        $log->info( "Indexing [", ref $self, ": ", $self->id, "]" );
     my $indexable = _indexable_object_text( $self, $p );
     my $wc = _tokenize( $self, $indexable );
-    DEBUG && LOG( LDEBUG, "Found the following tokens:", Dumper( $wc ) );
+    $log->is_debug &&
+        $log->debug( "Found the following tokens:", CTX->dump( $wc ) );
 
     # In the 'real world', we'd start a transaction here...
 
     my $remove_rv = remove_object_from_index( $self );
-    DEBUG && LOG( LINFO, "Results of removal $remove_rv" );
+    $log->is_info &&
+        $log->info( "Results of removal $remove_rv" );
     my $store_rv  = _store_terms( $self, $wc ) if ( keys %{ $wc } );
 
     # ... and then commit it here if everything went ok
@@ -187,9 +203,12 @@ sub reindex_object {
 
 sub remove_object_from_index {
     my ( $self, $p ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $object_key = $self->generate_object_key;
-    DEBUG && LOG( LINFO, "Removing from index ",
-                         '[', ref $self, ": ", $self->id, "]" );
+    $log->is_info &&
+        $log->info( "Removing from index ",
+                    '[', ref $self, ": ", $self->id, "]" );
     return eval { $self->db_delete({ table => $TABLE_NAME,
                                      where => 'object_key = ?',
                                      value => [ $object_key ] }) };
@@ -207,12 +226,14 @@ sub remove_object_from_index {
 
 sub _indexable_object_text {
     my ( $self, $p ) = @_;
+    my $log = get_logger( LOG_APP );
+
     $p ||= {};
 
     my $field_list = $p->{fulltext_field}
                      || $self->CONFIG->{fulltext_field};
     unless ( ref $field_list eq 'ARRAY' ) {
-        LOG( LERROR, "Cannot index object text -- no fields presented ",
+        $log->error( "Cannot index object text -- no fields presented ",
                      "in config file." );
         return undef;
     }
@@ -268,6 +289,8 @@ sub _tokenize {
 
 sub _store_terms {
     my ( $self, $terms ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $object_key = $self->generate_object_key;
     my $fields = join( ',', @SQL_FIELD_NAMES );
     my $values = join( ',', map { '?' } @SQL_FIELD_NAMES );
@@ -275,14 +298,15 @@ sub _store_terms {
        INSERT INTO $TABLE_NAME ( $fields  )
        VALUES ( $values )
     /;
-    my $sth = eval { $self->global_db_handle->prepare( $sql ) };
+    my $sth = eval { CTX->datasource( DS_NAME )->prepare( $sql ) };
     if ( $@ ) {
-        LOG( LERROR, "Failed to prepare: $sql\nError: $@" );
+        $log->error( "Failed to prepare: $sql\nError: $@" );
         oi_error "Failed to prepare statement for storing terms: $@";
     }
     my $count = 0;
     foreach my $term ( keys %{ $terms } ) {
-        DEBUG && LOG( LDEBUG, "Storing $object_key: $term [$terms->{$term}]" );
+        $log->is_debug &&
+            $log->debug( "Storing $object_key: $term [$terms->{$term}]" );
         eval {
             $sth->bind_param( SQL_ORDER_KEY + 1,   $object_key,       SQL_VARCHAR );
             $sth->bind_param( SQL_ORDER_TERM + 1,  $term,             SQL_VARCHAR );
@@ -290,7 +314,7 @@ sub _store_terms {
             $sth->execute;
             $count++;
         };
-        LOG( LERROR, "Failed to execute: $sql\n",
+        $log->error( "Failed to execute: $sql\n",
                      "Values: $object_key || $term || $terms->{ $term }\n",
                      "Error: $@" );
         oi_error "Failed executing term insertion: $@";
@@ -307,17 +331,17 @@ sub _store_terms {
 
 sub _execute_fulltext_search {
     my ( $class, $p ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $sql = $class->_build_sql_search_statement( $p->{terms} );
 
     my ( $sth );
-    my $server_config = CTX->server_config;
-    my $ds_name = $server_config->{fulltext}{datasource};
     eval {
-        $sth = CTX->datasource( $ds_name )->prepare( $sql );
+        $sth = CTX->datasource( DS_NAME )->prepare( $sql );
         $sth->execute( @{ $p->{terms} } );
     };
     if ( $@ ) {
-        LOG( LERROR, "Failed to fulltext search with\n$sql\nError: $@" );
+        $log->error( "Failed to fulltext search with\n$sql\nError: $@" );
         oi_error "Cannot execute fulltext search: $@";
     }
     return $sth;
@@ -383,6 +407,7 @@ sub _fetch_raw_fulltext_results {
 
 sub _screen_results {
     my ( $class, $results, $p ) = @_;
+    my $log = get_logger( LOG_APP );
 
     # If this was an AND search, knock off all the results that didn't
     # have matches for all the terms
@@ -397,8 +422,9 @@ sub _screen_results {
           map { delete $results->{ $_ } }
           grep { ( scalar keys %{ $results->{ $_ } } ) - 1 < $num_terms }
           keys %{ $results };
-        DEBUG && LOG( LDEBUG, "Removed [$num_removed] items from the list",
-                              "since they didn't match all the terms" );
+        $log->is_debug &&
+            $log->debug( "Removed [$num_removed] items from the list",
+                         "since they didn't match all the terms" );
     }
 
 }
@@ -414,12 +440,11 @@ OpenInteract2::FullText - Metadata layer for objects to implement simple full-te
 
 =head1 SYNOPSIS
 
- # In object's spops.perl file
- myobj => {
-  isa => [ qw/ OpenInteract2::FullText ... / ],
-  fulltext_field => [ qw/ description title / ],
-  ...
- }
+ # In object's spops.ini file
+ [myobj]
+  isa = OpenInteract2::FullText
+  fulltext_field = description
+  fulltext_field = title
  
  # All 'save()' calls to the object will trigger the object's
  # 'description' and 'title' fields being indexed.
@@ -428,6 +453,7 @@ OpenInteract2::FullText - Metadata layer for objects to implement simple full-te
                                         return   => 'raw',
                                         keywords => [ 'google', 'engine' ] });
  
+ # TODO
  # OPTIONAL: Declare your fulltext index to be stored on a
  # different database
  
@@ -632,7 +658,7 @@ None known.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2002 intes.net, inc.. All rights reserved.
+Copyright (c) 2001-2003 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
