@@ -1,6 +1,6 @@
 CREATE TABLE news (
  news_id       %%INCREMENT%%,
- posted_on     datetime not null, 
+ posted_on     timestamp not null, 
  posted_by     %%USERID_TYPE%% not null,
  title         varchar(75),
  news_item     blob,
@@ -9,7 +9,9 @@ CREATE TABLE news (
  image_align   varchar(5) null,
  section       varchar(20) default 'Public',
  active        char(3) default 'yes',
- expires_on    datetime,
- active_on     datetime,
+ previous_id   %%INCREMENT_TYPE%% null,
+ next_id       %%INCREMENT_TYPE%% null,
+ expires_on    timestamp,
+ active_on     timestamp,
  primary key   ( news_id )
 )
